@@ -116,7 +116,7 @@ XPCOMUtils.defineLazyGetter(this, "gABI", function aus_gABI() {
   catch (e) {
     LOG("gABI - XPCOM ABI unknown: updates are not possible.");
   }
-//@line 172 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/toolkit/mozapps/update/src/nsUpdateService.js.in"
+//@line 177 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/toolkit/mozapps/update/src/nsUpdateService.js.in"
   return abi;
 });
 
@@ -152,7 +152,7 @@ XPCOMUtils.defineLazyGetter(this, "gCanApplyUpdates", function aus_gCanApplyUpda
       updateTestFile.remove(false);
     updateTestFile.create(NORMAL_FILE_TYPE, FileUtils.PERMS_FILE);
     updateTestFile.remove(false);
-//@line 281 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/toolkit/mozapps/update/src/nsUpdateService.js.in"
+//@line 286 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/toolkit/mozapps/update/src/nsUpdateService.js.in"
   }
   catch (e) {
      LOG("gCanApplyUpdates - unable to apply updates. Exception: " + e);
@@ -205,7 +205,7 @@ function LOG(string) {
 }
 
 /**
-//@line 343 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/toolkit/mozapps/update/src/nsUpdateService.js.in"
+//@line 348 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/toolkit/mozapps/update/src/nsUpdateService.js.in"
  */
 function getPref(func, preference, defaultValue) {
   try {
@@ -235,10 +235,10 @@ function binaryToHex(input) {
 }
 
 /**
-//@line 378 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/toolkit/mozapps/update/src/nsUpdateService.js.in"
+//@line 383 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/toolkit/mozapps/update/src/nsUpdateService.js.in"
  */
 function getUpdateDirCreate(pathArray) {
-//@line 389 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/toolkit/mozapps/update/src/nsUpdateService.js.in"
+//@line 394 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/toolkit/mozapps/update/src/nsUpdateService.js.in"
   return FileUtils.getDir(KEY_APPDIR, pathArray, true);
 }
 
@@ -326,7 +326,7 @@ function writeStatusFile(dir, state) {
 }
 
 /**
-//@line 490 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/toolkit/mozapps/update/src/nsUpdateService.js.in"
+//@line 495 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/toolkit/mozapps/update/src/nsUpdateService.js.in"
  */
 function writeVersionFile(dir, version) {
   var versionFile = dir.clone();
@@ -1149,7 +1149,7 @@ UpdateService.prototype = {
     }
 
     /**
-//@line 1324 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/toolkit/mozapps/update/src/nsUpdateService.js.in"
+//@line 1329 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/toolkit/mozapps/update/src/nsUpdateService.js.in"
      */
 
     var neverPrefName = PREF_APP_UPDATE_NEVER_BRANCH + update.extensionVersion;
@@ -1176,7 +1176,7 @@ UpdateService.prototype = {
     }
 
     /**
-//@line 1366 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/toolkit/mozapps/update/src/nsUpdateService.js.in"
+//@line 1371 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/toolkit/mozapps/update/src/nsUpdateService.js.in"
      */
     if (update.type == "major") {
       LOG("Checker:_selectAndInstallUpdate - prompting because it is a major " +
@@ -1252,7 +1252,7 @@ UpdateService.prototype = {
 
     if (currentAddons.length > 0) {
       /**
-//@line 1459 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/toolkit/mozapps/update/src/nsUpdateService.js.in"
+//@line 1464 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/toolkit/mozapps/update/src/nsUpdateService.js.in"
        */
       this._incompatAddonsCount = currentAddons.length;
       LOG("UpdateService:_checkAddonCompatibility - checking for " +
@@ -2331,7 +2331,7 @@ Downloader.prototype = {
         var message = getStatusTextFromCode(vfCode, vfCode);
         this._update.statusText = message;
 
-        if (this._update.isCompleteUpdate)
+        if (this._update.isCompleteUpdate || this._update.patchCount != 2)
           deleteActiveUpdate = true;
 
         // Destroy the updates directory, since we're done with it.
@@ -2377,13 +2377,11 @@ Downloader.prototype = {
     this._request = null;
 
     if (state == STATE_DOWNLOAD_FAILED) {
-      if (!this._update.isCompleteUpdate) {
-        var allFailed = true;
-
-        // If we were downloading a patch and the patch verification phase
-        // failed, log this and then commence downloading the complete update.
+      var allFailed = true;
+      // Check if there is a complete update patch that can be downloaded.
+      if (!this._update.isCompleteUpdate && this._update.patchCount == 2) {
         LOG("Downloader:onStopRequest - verification of patch failed, " +
-            "downloading complete update");
+            "downloading complete update patch");
         this._update.isCompleteUpdate = true;
         var status = this.downloadUpdate(this._update);
 
@@ -2392,38 +2390,37 @@ Downloader.prototype = {
         } else {
           allFailed = false;
         }
-        // This will reset the |.state| property on this._update if a new
-        // download initiates.
       }
 
-      // if we still fail after trying a complete download, give up completely
       if (allFailed) {
-        // In all other failure cases, i.e. we're S.O.L. - no more failing over
-        // ...
+        LOG("Downloader:onStopRequest - all update patch downloads failed");
+        // If the update UI is not open (e.g. the user closed the window while
+        // downloading) and if at any point this was a foreground download
+        // notify the user about the error. If the update was a background
+        // update there is no notification since the user won't be expecting it.
+        var wm = Cc["@mozilla.org/appshell/window-mediator;1"].
+                 getService(Ci.nsIWindowMediator);
+        if (!wm.getMostRecentWindow(UPDATE_WINDOW_NAME)) {
+          try {
+            this._update.QueryInterface(Ci.nsIWritablePropertyBag);
+            var fgdl = this._update.getProperty("foregroundDownload");
+          }
+          catch (e) {
+LOG("Downloader:onStopRequest - not a foreground download");
+          }
 
-        // If this was ever a foreground download, and now there is no UI active
-        // (e.g. because the user closed the download window) and there was an
-        // error, we must notify now. Otherwise we can keep the failure to
-        // ourselves since the user won't be expecting it.
-        try {
-          this._update.QueryInterface(Ci.nsIWritablePropertyBag);
-          var fgdl = this._update.getProperty("foregroundDownload");
-        }
-        catch (e) {
-        }
-
-        if (fgdl == "true") {
-          var prompter = Cc["@mozilla.org/updates/update-prompt;1"].
-                         createInstance(Ci.nsIUpdatePrompt);
-          this._update.QueryInterface(Ci.nsIWritablePropertyBag);
-          this._update.setProperty("downloadFailed", "true");
-          prompter.showUpdateError(this._update);
+          if (fgdl == "true") {
+            LOG("Downloader:onStopRequest - foreground download... notifying " +
+                "user");
+            var prompter = Cc["@mozilla.org/updates/update-prompt;1"].
+                           createInstance(Ci.nsIUpdatePrompt);
+            prompter.showUpdateError(this._update);
+          }
         }
+        // Prevent leaking the update object (bug 454964).
+        this._update = null;
       }
-
-      // Prevent leaking the update object (bug 454964)
-      this._update = null;
-      // the complete download succeeded or total failure was handled, so exit
+      // A complete download has been initiated or the failure was handled.
       return;
     }
 
