@@ -59,9 +59,9 @@ pref("general.warnOnAboutConfig", true);
 pref("browser.bookmarks.max_backups",       5);
 
 pref("browser.cache.disk.enable",           true);
-//@line 63 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 63 "/builds/moz2_slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
 pref("browser.cache.disk.capacity",         51200);
-//@line 67 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 67 "/builds/moz2_slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
 pref("browser.cache.memory.enable",         true);
 //pref("browser.cache.memory.capacity",     -1);
 // -1 = determine dynamically, 0 = none, n = memory capacity in kilobytes
@@ -70,7 +70,7 @@ pref("browser.cache.disk_cache_ssl",        false);
 pref("browser.cache.check_doc_frequency",   3);
 
 pref("browser.cache.offline.enable",           true);
-//@line 76 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 76 "/builds/moz2_slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
 // offline cache capacity in kilobytes
 pref("browser.cache.offline.capacity",         512000);
 
@@ -81,7 +81,7 @@ pref("offline-apps.quota.max",        204800);
 // the user should be warned if offline app disk usage exceeds this amount
 // (in kilobytes)
 pref("offline-apps.quota.warn",        51200);
-//@line 92 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 92 "/builds/moz2_slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
 // Fastback caching - if this pref is negative, then we calculate the number
 // of content viewers to cache based on the amount of available memory.
@@ -145,11 +145,11 @@ pref("media.enforce_same_site_origin", false);
 // Media cache size in kilobytes
 pref("media.cache_size", 51200);
 
-//@line 156 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 156 "/builds/moz2_slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
 pref("media.ogg.enabled", true);
-//@line 159 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 159 "/builds/moz2_slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
 pref("media.wave.enabled", true);
-//@line 161 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 161 "/builds/moz2_slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
 // Whether to autostart a media element with an |autoplay| attribute
 pref("media.autoplay.enabled", true);
@@ -161,13 +161,17 @@ pref("gfx.color_management.display_profile", "");
 pref("gfx.color_management.rendering_intent", 0);
 
 pref("gfx.downloadable_fonts.enabled", true);
+pref("gfx.downloadable_fonts.sanitize", true);
+//@line 176 "/builds/moz2_slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
+pref("gfx.downloadable_fonts.sanitize.preserve_otl_tables", true);
+//@line 178 "/builds/moz2_slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
 pref("accessibility.browsewithcaret", false);
 pref("accessibility.warn_on_browsewithcaret", true);
 
 pref("accessibility.browsewithcaret_shortcut.enabled", true);
 
-//@line 179 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 185 "/builds/moz2_slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
 // Tab focus model bit field:
 // 1 focuses text controls, 2 focuses other form elements, 4 adds links.
 // Most users will want 1, 3, or 7.
@@ -180,7 +184,7 @@ pref("accessibility.tabfocus_applies_to_xul", false);
 // unless this preference was set manually
 pref("ui.scrollToClick", 0);
 
-//@line 195 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 201 "/builds/moz2_slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
 pref("accessibility.usetexttospeech", "");
 pref("accessibility.usebrailledisplay", "");
@@ -524,9 +528,9 @@ pref("dom.storage.enabled", true);
 pref("dom.storage.default_quota",      5120);
 
 // Parsing perf prefs. For now just mimic what the old code did.
-//@line 539 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 545 "/builds/moz2_slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
 pref("content.sink.pending_event_mode", 0);
-//@line 541 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 547 "/builds/moz2_slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
 // Disable popups from plugins by default
 //   0 = openAllowed
@@ -575,7 +579,7 @@ pref("network.protocol-handler.external.data", false);
 pref("network.protocol-handler.external.ms-help", false);
 pref("network.protocol-handler.external.shell", false);
 pref("network.protocol-handler.external.vnd.ms.radio", false);
-//@line 592 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 598 "/builds/moz2_slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.disk", false);
 pref("network.protocol-handler.external.disks", false);
 pref("network.protocol-handler.external.afp", false);
@@ -739,6 +743,9 @@ pref("network.IDN.whitelist.xn--fiqz9s", true); // Traditional
 pref("network.IDN.whitelist.xn--fiqs8s", true); // Simplified
 // hk, Hong Kong, .<Hong Kong>
 pref("network.IDN.whitelist.xn--j6w193g", true);
+// ir, Iran, <.Iran> with variants
+pref("network.IDN.whitelist.xn--mgba3a4f16a", true);
+pref("network.IDN.whitelist.xn--mgba3a4fra", true);
 // jo, Jordan, .<Al-Ordon>
 pref("network.IDN.whitelist.xn--mgbayh7gpa", true);
 // ru, Russian Federation, .<RF>
@@ -838,7 +845,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 860 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 869 "/builds/moz2_slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
 // Controls which NTLM authentication implementation we default to. True forces
 // the use of our generic (internal) NTLM authentication implementation vs. any
@@ -1259,15 +1266,15 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1678 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 1687 "/builds/moz2_slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2102 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2111 "/builds/moz2_slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2305 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2314 "/builds/moz2_slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2401 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2410 "/builds/moz2_slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2404 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2413 "/builds/moz2_slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.hosts.smtp_server", "localhost");
 pref("network.hosts.pop_server", "pop");
@@ -1537,15 +1544,15 @@ pref("ui.panel.default_level_parent", true);
 
 pref("mousewheel.system_scroll_override_on_root_content.enabled", false);
 
-//@line 2676 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2685 "/builds/moz2_slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2744 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2753 "/builds/moz2_slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2770 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2779 "/builds/moz2_slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2790 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2799 "/builds/moz2_slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2798 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2807 "/builds/moz2_slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
@@ -1582,9 +1589,9 @@ pref("image.cache.timeweight", 500);
 // The default Accept header sent for images loaded over HTTP(S)
 pref("image.http.accept", "image/png,image/*;q=0.8,*/*;q=0.5");
 
-//@line 2840 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2849 "/builds/moz2_slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2845 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2854 "/builds/moz2_slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
 // Enable/Disable the geolocation API for content
 pref("geo.enabled", true);
